
# GMiner Command Reference

## Miner Options
- `--help` or `-h` - Display available options.
- `--version` or `-v` - Print program version.
- `--user_id` - Print user ID.
- `--algo` or `-a` - Mining algorithm (for example: 'ethash', 'kawpow', 'cuckatoo32', 'beamhash').
- `--list_devices` - List devices available for mining.
- `--contest_wallet` - Ethash wallet, required to participate in contest.
- `--server` or `-s` - Mining pool address (for example: 'eu.btgpool.pro', 'eu1.zhash.pro').
- `--port` or `-n` - Mining pool port (for example: '5057', '1445').
- `--user` or `-u` - Mining pool login or wallet address, worker's name can be specified with a dot (for example: 'sRuJK1BmA758GbOn.worker').
- `--worker` - Worker name for Ethash stratum, for pools that do not support wallet.worker (for example: 'rig0').
- `--pass` or `-p` - Worker password or default pool password, default is 'x'.
- `--ssl` - Enable/disable secure connection with mining pool ('0' - off or '1' - on), must be supported by pool, default is '0'.
- `--proxy` - SOCKS5 proxy server address (for example: 31.7.232.178:1080).
- `--proto` - Specify stratum protocol mode, possible values: proxy and stratum (useful for Ethash mining), default is 'proxy'.
- `--dag_mode` - Space-separated list of Dag file modes (0 - auto, 1 - single, 2 - double), default is '0'.
- `--safe_dag` - Space-separated list of DAG generation modes (0 - auto, 1 - fast mode, 2 - safe mode), only Nvidia GPUs are supported.
- `--dag_limit` - Space-separated list of Dag file size limits in megabytes, disable with 0, default is '0'.
- `--cache_dag` - Enable/disable caching of DAG file for mining Ethash + Zilliqa or Nicehash ('0' - off or '1' - on), default is '1'.
- `--dag_gen_limit` - Max number of parallel DAG generations, 0 - disable limit, default is '0'.
- `--devices` or `-d` - Space-separated list of cuda devices, default is all available devices.
- `--kernel` or `-k` - Space-separated list of kernel numbers for each device (0 - auto, up to 6 kernels supported).
- `--mt` - Space-separated list of memory tweak numbers (range from 0 to 6, 0 - disable tweaks), Nvidia GPUs with GDDR5X/GDDR5.
- `--fan` - Space-separated list of fan speed for each device in % (0 - ignore), Windows only.
- `--pl` - Space-separated list of power limits for each device in % (0 - ignore), Windows only.
- `--cclock` - Core clock offsets (Nvidia) or absolute clocks (AMD) for each device in MHz (0 - ignore), Windows only.
- `--mclock` - Memory clock offsets (Nvidia) or absolute clocks (AMD) for each device in MHz (0 - ignore), Windows only.
- `--cvddc` - Core voltage offsets in % (Nvidia) or absolute voltages (AMD) in mV (0 - ignore), Windows only.
- `--lock_voltage` - Locked voltage points for each device in mV (0 - ignore), Windows/Nvidia only.
- `--lock_cclock` - Locked core clock points for each device in MHz (0 - ignore), Nvidia only.
- `--p2state` - Enable/disable P2 state, Nvidia only.
- `--tfan` - Target temperatures for fans (0 - ignore), Windows only.
- `--templimit` or `-t` - Temperature limits, stops mining until GPU cools down.
- `--templimit_mem` or `-tm` - Memory temperature limits, stops mining until GPU cools down.
- `--logfile` or `-l` - Filename to save logs on disk.
- `--log_date` - Enable/disable date in each message, default is '0'.
- `--log_stratum` - Enable/disable communication with the server, default is '0'.
- `--log_newjob` - Enable/disable information about new jobs, default is '1'.
- `--color` or `-c` - Enable/disable color output for console, default is '1'.
- `--watchdog` or `-w` - Enable/disable watchdog to restart miner on failures.
- `--watchdog_restart_delay` - Miner restart delay for watchdog in seconds, default is '10'.
- `--watchdog_mode` - Watchdog action on miner quit (0 - restart miner, 1 - reboot system), default is '0'.
- `--min_rig_speed` - Minimal rig speed, quits if average speed drops below value.
- `--report_interval` - Statistics report interval in seconds, default is '30'.
- `--api` - Telemetry server port, allows monitoring miner status remotely.
- `--config` - Specify configuration file.
- `--pec` - Enable/disable power efficiency calculator, default is '1'.
- `--electricity_cost` - Cost of electricity in USD per kWh, miner will report $ spent on mining.
- `--intensity` or `-i` - Intensity values (1-100), default is '100'.
- `--share_check` - Enable/disable share check on CPU (for Ethash), default is '1'.
- `--nvml` - Enable/disable NVML (statistic library for CUDA), default is '1'.
- `--cuda` - Enable/disable CUDA platform, default is '1'.
- `--opencl` - Enable/disable OpenCL platform, default is '1'.
- `--lhr` - List of LHR modes, Nvidia only.
- `--lhr_tune` - List of LHR tune values (unlock %), Nvidia only.
- `--lhr_autotune` - LHR auto-tune, 0 - off, 1 - on, Nvidia only.
- `--lhr_mode` - LHR mode (0 - power save, 1 - max performance), Nvidia only.

## Fast Start Example
For a quick start with Ethash:
```bash
miner --algo ethash --server eth.2miners.com:2020 --user 0x5218597d48333d4a70cce91e810007b37e2937b5.worker1
```
